@@ -1,83 +1,10 @@
 # FTN::JAM
 
+package FTN::JAM;
+
 use warnings;
 use strict;
 
-package FTN::JAM::Subfields;
-
-use Readonly;
-
-Readonly our $OADDRESS    => 0;
-Readonly our $DADDRESS    => 1;
-Readonly our $SENDERNAME  => 2;
-Readonly our $RECVRNAME   => 3;
-Readonly our $MSGID       => 4;
-Readonly our $REPLYID     => 5;
-Readonly our $SUBJECT     => 6;
-Readonly our $PID         => 7;
-Readonly our $TRACE       => 8;
-Readonly our $ENCLFILE    => 9;
-Readonly our $ENCLFWALIAS => 10;
-Readonly our $ENCLFREQ    => 11;
-Readonly our $ENCLFILEWC  => 12;
-Readonly our $ENCLINDFILE => 13;
-Readonly our $EMBINDAT    => 1000;
-Readonly our $FTSKLUDGE   => 2000;
-Readonly our $SEENBY2D    => 2001;
-Readonly our $PATH2D      => 2002;
-Readonly our $FLAGS       => 2003;
-Readonly our $TZUTCINFO   => 2004;
-Readonly our $UNKNOWN     => 0xffff;
-
-package FTN::JAM::Attr;
-
-use Readonly;
-
-Readonly our $LOCAL       => 0x00000001;
-Readonly our $INTRANSIT   => 0x00000002;
-Readonly our $PRIVATE     => 0x00000004;
-Readonly our $READ        => 0x00000008;
-Readonly our $SENT        => 0x00000010;
-Readonly our $KILLSENT    => 0x00000020;
-Readonly our $ARCHIVESENT => 0x00000040;
-Readonly our $HOLD        => 0x00000080;
-Readonly our $CRASH       => 0x00000100;
-Readonly our $IMMEDIATE   => 0x00000200;
-Readonly our $DIRECT      => 0x00000400;
-Readonly our $GATE        => 0x00000800;
-Readonly our $FILEREQUEST => 0x00001000;
-Readonly our $FILEATTACH  => 0x00002000;
-Readonly our $TRUNCFILE   => 0x00004000;
-Readonly our $KILLFILE    => 0x00008000;
-Readonly our $RECEIPTREQ  => 0x00010000;
-Readonly our $CONFIRMREQ  => 0x00020000;
-Readonly our $ORPHAN      => 0x00040000;
-Readonly our $ENCRYPT     => 0x00080000;
-Readonly our $COMPRESS    => 0x00100000;
-Readonly our $ESCAPED     => 0x00200000;
-Readonly our $FPU         => 0x00400000;
-Readonly our $TYPELOCAL   => 0x00800000;
-Readonly our $TYPEECHO    => 0x01000000;
-Readonly our $TYPENET     => 0x02000000;
-Readonly our $NODISP      => 0x20000000;
-Readonly our $LOCKED      => 0x40000000;
-Readonly our $DELETED     => 0x80000000;
-
-package FTN::JAM::Errnum;
-
-use Readonly;
-
-Readonly our $IO_ERROR           => 1;
-Readonly our $BASE_EXISTS        => 2;
-Readonly our $BASEHEADER_CORRUPT => 3;
-Readonly our $MSGHEADER_CORRUPT  => 4;
-Readonly our $MSGHEADER_UNKNOWN  => 5;
-Readonly our $MSG_DELETED        => 6;
-Readonly our $BASE_NOT_LOCKED    => 7;
-Readonly our $USER_NOT_FOUND     => 8;
-
-package FTN::JAM;
-
 use Carp;
 use Time::Local;
 use Time::Zone;
@@ -90,11 +17,11 @@ FTN::JAM - A Perl extension for handleing JAM messagebases.
 
 =head1 VERSION
 
-Version 0.14
+Version 0.20
 
 =cut
 
-our $VERSION = '0.14';
+our $VERSION = '0.20';
 
 =head1 SYNOPSIS
 
@@ -1294,7 +1221,7 @@ L<http://ftnpl.sourceforge.net/ftnpljam.html>
 
 =item * Browse the FTN::JAM GIT repository at SourceForge
 
-L<http://ftnpl.git.sourceforge.net/git/gitweb.cgi?p=ftnpl/ftn-jam.git>
+L<http://sourceforge.net/p/ftnpl/ftn-jam/code>
 
 =item * RT: CPAN's request tracker
 
@@ -1325,7 +1252,7 @@ can be found at L<https://bitbucket.org/johanbilling/jampm/overview>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010-2011 Robert James Clay, all rights reserved.
+Copyright 2010-2012 Robert James Clay, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
